==> aliyun_python_sdk_cams-1.0.6-py2.py3-none-any.whl: aliyunsdkcams/request/v20200606/DeleteChatappTemplateRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcams.endpoint import endpoint_data

class DeleteChatappTemplateRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cams', '2020-06-06', 'DeleteChatappTemplate')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CustWabaId(self): # String
		return self.get_query_params().get('CustWabaId')

	def set_CustWabaId(self, CustWabaId):  # String
		self.add_query_param('CustWabaId', CustWabaId)
	def get_IsvCode(self): # String
		return self.get_query_params().get('IsvCode')

	def set_IsvCode(self, IsvCode):  # String
		self.add_query_param('IsvCode', IsvCode)
	def get_CustSpaceId(self): # String
		return self.get_query_params().get('CustSpaceId')

	def set_CustSpaceId(self, CustSpaceId):  # String
		self.add_query_param('CustSpaceId', CustSpaceId)
	def get_TemplateCode(self): # String
		return self.get_query_params().get('TemplateCode')

	def set_TemplateCode(self, TemplateCode):  # String
		self.add_query_param('TemplateCode', TemplateCode)

==> aliyun_python_sdk_cams-1.0.8-py2.py3-none-any.whl: aliyunsdkcams/request/v20200606/DeleteChatappTemplateRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcams.endpoint import endpoint_data

class DeleteChatappTemplateRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'cams', '2020-06-06', 'DeleteChatappTemplate','cams')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CustWabaId(self): # String
		return self.get_query_params().get('CustWabaId')

	def set_CustWabaId(self, CustWabaId):  # String
		self.add_query_param('CustWabaId', CustWabaId)
	def get_IsvCode(self): # String
		return self.get_query_params().get('IsvCode')

	def set_IsvCode(self, IsvCode):  # String
		self.add_query_param('IsvCode', IsvCode)
	def get_CustSpaceId(self): # String
		return self.get_query_params().get('CustSpaceId')

	def set_CustSpaceId(self, CustSpaceId):  # String
		self.add_query_param('CustSpaceId', CustSpaceId)
	def get_TemplateCode(self): # String
		return self.get_query_params().get('TemplateCode')

	def set_TemplateCode(self, TemplateCode):  # String
		self.add_query_param('TemplateCode', TemplateCode)
